@@ -86,35 +86,37 @@ getRaster <- function(surface = "Plasmodium falciparum PR2-10",
   
   
   if(length(raster_code_list)!=length(surface)&any(grepl("anoph", raster_code_list, ignore.case = T))){
-    
-  for(i in surface){
-    if(length(as.character(available_rasters$raster_code[available_rasters$title%in%i]))>1){
-      raster_code_list_i <- as.character(available_rasters$raster_code[available_rasters$title%in%i])
       
-      idx <- raster_code_list %in% raster_code_list_i
-      
-      if(is.null(vector_year)){
-      vector_year <- max(as.numeric(substr(raster_code_list_i, 1, 4)))
+    for(i in surface){
+      if(length(as.character(available_rasters$raster_code[available_rasters$title%in%i]))>1){
+        raster_code_list_i <- as.character(available_rasters$raster_code[available_rasters$title%in%i])
+        
+        idx <- raster_code_list %in% raster_code_list_i
+        
+        if(is.null(vector_year)){
+        vector_year <- max(as.numeric(substr(raster_code_list_i, 1, 4)))
+        }
+        
+         raster_code_list <- c(raster_code_list[!idx], grep(vector_year, raster_code_list, value = TRUE))
+        
       }
       
-       raster_code_list <- c(raster_code_list[!idx], grep(vector_year, raster_code_list, value = TRUE))
-      
     }
-    
-  }
-    
+      
   }
 
   if (anyNA(raster_code_list)) {
-    stop(
-      "The following surfaces have been incorrectly specified, use listRaster to confirm spelling of raster 'title':\n",
-      paste("  -", surface[is.na(raster_code_list)], collapse = "\n")
-    )  
+    message1 <- "The following surfaces have been incorrectly specified, use listRaster to confirm spelling of raster 'title':"
+    
+                      
+    message(message1, '\n', paste("  -", surface[is.na(raster_code_list)], collapse = "\n"))  
+    return(paste0(message1, paste("  ", surface[is.na(raster_code_list)], collapse = ", ")))
   } else if( length(raster_code_list) == 0 ) {
-    stop(
-      "The following surfaces have been incorrectly specified, use listRaster to confirm spelling of raster 'title':\n",
-      paste("  -", surface, collapse = "\n")
-    )  
+    message1 <- "The following surfaces have been incorrectly specified, use listRaster to confirm spelling of raster 'title':"
+    
+    
+    message(message1, '\n', paste("  -", surface, collapse = "\n"))  
+    return(paste0(message1, paste("  ", surface, collapse = ", ")))
     
   } else {
     message("All specified surfaces are available to download.")
@@ -189,9 +191,10 @@ getRaster <- function(surface = "Plasmodium falciparum PR2-10",
   }
   
   if (year_warnings > 0) {
-    stop(
-      "Specified surfaces are not available for all requested years,. \n Try downloading surfaces separately or double-check availability of 'surface'-'year' combinations using listRaster()\n see warnings() for more info."
-    )
+    message <- "Specified surfaces are not available for all requested years. \n Try downloading surfaces separately or double-check availability of 'surface'-'year' combinations using listRaster()\n see warnings() for more info."
+
+    message(message)
+    return(message)
   }
   
   ## create directory to which rasters will be downloaded
@@ -231,7 +234,9 @@ getRaster <- function(surface = "Plasmodium falciparum PR2-10",
   
   # Return error if new rasters are not found
   if (length(newrst) == 0) {
-    stop("Raster download error: check surface and/or extent are specified correctly")
+    message <- "Raster download error: check surface and/or extent are specified correctly"
+    message(message)
+    return(message)
     # If only one new raster is found, read this in
   } else if (length(newrst) == 1) {
     rst_dl <- raster::raster(file.path(rstdir, newrst))
@@ -375,7 +380,7 @@ download_rst <-
       
       if (!"image/geotiff" %in% r$headers$`content-type`) {
         file.remove(rst_path)
-        warning(
+        message(
           "Raster download error - check ",
           raster_code,
           " surface is available for specified extent at map.ox.ac.uk/explorer."
@@ -393,11 +398,12 @@ download_rst <-
     }
     
     if (download_warnings > 0) {
-      stop(download_warnings,
-           " Raster download error(s) check warnings() for details.")
+      message <- paste0(download_warnings, " Raster download error(s). Details have been returned.")
+      message(message)
+      return(message)
     }
     
-  }
+}
 
 
 # TEST_SHP <- getShp(ISO = "MDG", admin_level = "admin0")
